@@ -1,10 +1,10 @@
-/* *************************************************************************
-   ***                               dhelp                               *** 
-   ***                      Debian online help system                    ***
-   *************************************************************************
-   ***  Copyright (c) 1997-98 by Marco Budde (Budde@tu-harburg.d400.de)  ***
-   ***                         GNU GPL license                           ***
-   ************************************************************************* */
+/* ********************************************************************
+   ***                             dhelp                            *** 
+   ***                    Debian online help system                 ***
+   ********************************************************************
+   ***  Copyright (c) 1997-99 by Marco Budde (Budde@tu-harburg.de)  ***
+   ***                         GNU GPL license                      ***
+   ******************************************************************** */
 
 
 #include <stdio.h>
@@ -114,7 +114,7 @@ void rm_r (char *dirname)
   DIR *dir;
   struct dirent *dir_entry;
   struct stat buf;
-  char zw[200];
+  char zw[MAXPATHLEN];
 
   if ((dir = opendir (dirname)) == NULL)
     return;
@@ -308,7 +308,7 @@ void html_error (FILE *out)
 
 void html_w_head (FILE *out, DB *tdb)
 {
-  char zw[60], zw2[60];
+  char zw[MAXPATHLEN], zw2[100];
   char cwd[MAXPATHLEN];
 
   clearerr (out);
@@ -333,15 +333,17 @@ void html_w_head (FILE *out, DB *tdb)
 void html_w_tail (FILE *out)
 {
   char cwd[MAXPATHLEN];
-  int  lang = 4;
-  char *language[] = { "", "de/", "it/", "es/", "fr/" };
-  char *search[] = { "Search", "Suche", "Ricerca", "Buscar", "Rechercher" };
-  char *info[] = { "info documents", "info Dokumente", "documenti info", 
-                   "documentos info", "Pages info" };
-  char *man[] = { "man pages", "Handbcher", "pagine di manuale", 
+  int  lang = 5;
+  char *language[] = { "", "de/", "da/", "it/", "es/", "fr/" };
+  char *search[] = { "Search", "Suche", "Sg", "Ricerca", "Buscar",
+                     "Rechercher" };
+  char *info[] = { "info documents", "info Dokumente", "info dokumenter",
+                   "documenti info", "documentos info", "Pages info" };
+  char *man[] = { "man pages", "Handbcher", "manual", "pagine di manuale", 
                   "pginas de manual", "Pages de manuel" };
-  char *other[] = { "other documents", "andere Dokumente", "altri documenti",
-                    "Otros documentos", "Autres documents" };
+  char *other[] = { "other documents", "andere Dokumente", "andre dokumenter",
+                    "altri documenti", "Otros documentos", 
+                    "Autres documents" };
   int  i;
 
   clearerr (out);
@@ -372,7 +374,7 @@ void html_w_tail (FILE *out)
 
 void html_w_item (tItem *item, FILE *out)
 {
-  char zw[60];
+  char zw[MAXPATHLEN];
 
   clearerr (out);
 
@@ -387,8 +389,8 @@ void html_w_item (tItem *item, FILE *out)
 
 int html_w_item_links (DB *db, DB *tdb, tItem *item)
 {
-  char cwd[200];
-  char dir[200], *dir_ptr;
+  char cwd[MAXPATHLEN];
+  char dir[MAXPATHLEN], *dir_ptr;
   FILE *out; 
 
   path_index_cwd (cwd); 
@@ -433,7 +435,7 @@ int html_w_dir_links (char *dirname, DB *tdb)
   struct dirent *dir_entry;
   struct stat buf;
   char zw[MAXPATHLEN];
-  char relpath[60];
+  char relpath[MAXPATHLEN];
 
   strcpy (zw, dirname);
   strcat (zw, "/index.html");
@@ -559,22 +561,26 @@ int get_item (FILE *fd, char *filename, tItem *item)
     if (strncmp ("<directory>", zw, 11) == 0) 
     {
       strncpy (item->dir, zw+11, sizeof (item->dir));
+      item->dir[sizeof(item->dir)-1] = '\0';
       strdel (item->dir);
     }
     if (strncmp ("<dirtitle>", zw, 10) == 0)
     {
       strncpy (item->dtitle, zw+10, sizeof (item->dtitle));
+      item->dtitle[sizeof(item->dtitle)-1] = '\0';
       strdel (item->dtitle);
     }
     if (strncmp ("<linkname>", zw, 10) == 0)
     {
       strncpy (item->name, zw+10, sizeof (item->name));
+      item->name[sizeof(item->name)-1] = '\0';
       strdel (item->name);
     }
     if (strncmp ("<filename>", zw, 10) == 0)
     {
       strcpy (item->file, filename);          /* Verzeichnisname */
       strncat (item->file, zw+10, sizeof (item->file) - strlen (filename));
+      item->file[sizeof(item->file)-1] = '\0';
       strdel (item->file);
     }
     if (strncmp ("<description>", zw, 13) == 0)
@@ -584,7 +590,10 @@ int get_item (FILE *fd, char *filename, tItem *item)
       {
         cnt = cnt + strlen (zw);
         if (cnt < sizeof (item->descrip))
+	{
           strcat (item->descrip, zw);
+          item->descrip[sizeof(item->descrip)-1] = '\0';
+        }
         if ((fgets (zw, sizeof(zw), fd)) == NULL)
           return 1;
       } 
